'--------------------
' Determine script folder and name
'--------------------
scriptName = wscript.ScriptName
scriptFull = wscript.ScriptFullName
scriptParent = Left( scriptFull, InStr(scriptFull, scriptName) - 1 )

xlsTemplate = scriptParent & "Archimate Analysis Tool Template.xlsx"

'--------------------
' Displaying File Open Dialog
'--------------------

Const msoFileDialogOpen = 1

msgbox "Archimate Model Exchange File Analyzer v3.0" & vbCRLF & vbCRLF & "Created By Paul Goes - June 2015"

Set fso = CreateObject("Scripting.FileSystemObject")
Set objWord = CreateObject("Word.Application")

Set WshShell = CreateObject("WScript.Shell")

strInitialPath = WshShell.ExpandEnvironmentStrings("%USERPROFILE%") & "\Desktop\"

objWord.ChangeFileOpenDirectory(strInitialPath)

With objWord.FileDialog(msoFileDialogOpen)
   .Title = "Select the Archimate Model Exchange file to process"

   .AllowMultiSelect = False

   .Filters.Clear

   .Filters.Add "Archimate Model files", "*.xml"
   .Filters.Add "All files", "*.*"

   If .Show = -1 Then
      
      For Each File in .SelectedItems 
        
		 fileAbsolute = fso.GetAbsolutePathName(File)
		 fileParent   = fso.GetParentFolderName(File)
		 fileBaseName = fso.GetBaseName(File)
		 fileName     = fso.GetFileName(File)
		 
      Next    

   End If
   
End With 

objWord.Quit

inputFile = fileAbsolute

If inputFile = "" Then

	msgbox "Archimate Model Exchange File Analyzer v3.0" & vbCRLF & vbCRLF & "No file to analyze !"
	wScript.Quit
	
End If

logFile   = fileParent & "\" & fileBaseName & ".log"
xlsFile   = fileParent & "\" & fileBaseName & ".xlsx"
pdfFile   = fileParent & "\" & fileBaseName & ".pdf"


'--------------------
' Create logfile
'--------------------

Set objFSO = CreateObject("Scripting.FileSystemObject")
Set objLog = objFSO.CreateTextFile(logFile)

objLog.WriteLine "------------------------------------------------------------"
objLog.WriteLine "Archimate Analyze Tool log.txt"
objLog.WriteLine "------------------------------------------------------------"
objLog.WriteLine " "


'--------------------
' Open model file
'--------------------

Set xmlDoc = _
  CreateObject("Microsoft.XMLDOM")


msgbox "Archimate Model Exchange File Analyzer v3.0" & vbCRLF & vbCRLF & "Analyzing file: " & fileName
  
xmlDoc.Async = "False"
xmlDoc.Load(inputFile)

ns = "http://www.opengroup.org/xsd/archimate"


'--------------------
' Retrieve model name
'--------------------

Set modelObj = xmlDoc.selectSingleNode("//model")	
Set modelNameObj = modelObj.selectSingleNode("name")

modelName = modelNameObj.Text

call writeLog("Analysing model : " & modelName)


'--------------------
' Analyse elements
'--------------------

call writeLog(" ")
call writeLog("Analysing elements ...")
call writeLog(" ")

cnt_elements = 0

cnt_BusinessActor = 0			: cnt_BusinessInterface = 0			: cnt_BusinessRole = 0		
cnt_BusinessCollaboration = 0	: cnt_Location = 0					: cnt_BusinessService = 0 
cnt_BusinessProcess = 0			: cnt_BusinessFunction = 0			: cnt_BusinessInteraction = 0
cnt_BusinessEvent = 0			: cnt_Value = 0 					: cnt_Product = 0
cnt_Meaning = 0 				: cnt_Contract = 0					: cnt_BusinessObject = 0	
cnt_Representation = 0

cnt_ApplicationInterface = 0	: cnt_ApplicationComponent = 0		: cnt_ApplicationCollaboration = 0
cnt_ApplicationService = 0		: cnt_ApplicationFunction = 0		: cnt_ApplicationInteraction = 0
cnt_DataObject = 0

cnt_CommunicationPath = 0 		: cnt_Network = 0					: cnt_InfrastructureInterface = 0
cnt_Node = 0 					: cnt_Device = 0 					: cnt_InfrastructureService = 0
cnt_InfrastructureFunction = 0 	: cnt_SystemSoftware = 0			: cnt_Artifact = 0

cnt_Requirement = 0				: cnt_Constraint = 0				: cnt_Principle = 0
cnt_Goal = 0					: cnt_Stakeholder = 0				: cnt_Assessment = 0
cnt_Driver = 0

cnt_WorkPackage = 0				: cnt_Deliverable = 0				: cnt_Plateau = 0
cnt_Gap = 0 


Set setElements = xmlDoc.selectNodes("//element")											' Select all element nodes

For Each element in setElements																' Loop through all element nodes
   
	cnt_elements = cnt_elements + 1
   
	elementID    = element.getAttribute("identifier")
	elementType  = element.getAttribute("xsi:type")
	
	Set elementLabel = element.selectSingleNode("label")
	
	If Not elementLabel Is Nothing Then
		elementName  = elementLabel.Text
	Else
		elementName  = "No Name"
	End If
	
	call writeLog("Found element : "& elementID & " - " & elementType & ": " & elementName)
	
	Select Case elementType
	
		Case "BusinessActor" 			cnt_BusinessActor = cnt_BusinessActor+1
		Case "BusinessInterface" 		cnt_BusinessInterface = cnt_BusinessInterface+1
		Case "BusinessRole" 			cnt_BusinessRole = cnt_BusinessRole+1
		Case "BusinessCollaboration" 	cnt_BusinessCollaboration = cnt_BusinessCollaboration+1
		Case "Location" 				cnt_Location = cnt_Location+1
		Case "BusinessService" 			cnt_BusinessService = cnt_BusinessService+1
		Case "BusinessProcess" 			cnt_BusinessProcess = cnt_BusinessProcess+1
		Case "BusinessFunction" 		cnt_BusinessFunction = cnt_BusinessFunction+1
		Case "BusinessInteraction" 		cnt_BusinessInteraction = cnt_BusinessInteraction+1
		Case "BusinessEvent" 			cnt_BusinessEvent = cnt_BusinessEvent+1
		Case "Value" 					cnt_Value = cnt_Value+1
		Case "Product" 					cnt_Product = cnt_Product+1
		Case "Meaning" 					cnt_Meaning = cnt_Meaning+1
		Case "Contract" 				cnt_Contract = cnt_Contract+1
		Case "BusinessObject" 			cnt_BusinessObject = cnt_BusinessObject+1
		Case "Representation" 			cnt_Representation = cnt_Representation+1
		
		Case "ApplicationInterface" 	cnt_ApplicationInterface = cnt_ApplicationInterface+1
		Case "ApplicationComponent" 	cnt_ApplicationComponent = cnt_ApplicationComponent+1
		Case "ApplicationCollaboration" cnt_ApplicationCollaboration = cnt_ApplicationCollaboration+1
		Case "ApplicationService" 		cnt_ApplicationService = cnt_ApplicationService+1
		Case "ApplicationFunction" 		cnt_ApplicationFunction = cnt_ApplicationFunction+1
		Case "ApplicationInteraction" 	cnt_ApplicationInteraction = cnt_ApplicationInteraction+1
		Case "DataObject" 				cnt_DataObject = cnt_DataObject+1
		
		Case "CommunicationPath" 		cnt_CommunicationPath = cnt_CommunicationPath+1
		Case "Network" 					cnt_Network = cnt_Network+1
		Case "InfrastructureInterface" 	cnt_InfrastructureInterface = cnt_InfrastructureInterface+1
		Case "Node" 					cnt_Node = cnt_Node+1
		Case "Device" 					cnt_Device = cnt_Device+1
		Case "InfrastructureService" 	cnt_InfrastructureService = cnt_InfrastructureService+1
		Case "InfrastructureFunction" 	cnt_InfrastructureFunction = cnt_InfrastructureFunction+1
		Case "SystemSoftware" 			cnt_SystemSoftware = cnt_SystemSoftware+1
		Case "Artifact" 				cnt_Artifact = cnt_Artifact+1
		
		Case "Requirement" 				cnt_Requirement = cnt_Requirement+1
		Case "Constraint" 				cnt_Constraint = cnt_Constraint+1
		Case "Principle" 				cnt_Principle = cnt_Principle+1
		Case "Goal" 					cnt_Goal = cnt_Goal+1
		Case "Stakeholder" 				cnt_Stakeholder = cnt_Stakeholder+1
		Case "Assessment" 				cnt_Assessment = cnt_Assessment+1
		Case "Driver" 					cnt_Driver = cnt_Driver+1
		
		Case "WorkPackage" 				cnt_WorkPackage = cnt_WorkPackage+1
		Case "Deliverable" 				cnt_Deliverable = cnt_Deliverable+1
		Case "Plateau" 					cnt_Plateau = cnt_Plateau+1
		Case "Gap" 						cnt_Gap = cnt_Gap+1
		
		Case "Junction" 				cnt_Elements = cnt_Elements-1
		
	End Select
	
Next	

cnt_BL_Passive = 0		: cnt_BL_Behavior = 0		: cnt_BL_Active = 0
cnt_AL_Passive = 0		: cnt_AL_Behavior = 0		: cnt_AL_Active = 0
cnt_TL_Passive = 0		: cnt_TL_Behavior = 0		: cnt_TL_Active = 0

cnt_BL_Passive  	= cnt_Value + cnt_Product + cnt_Meaning + cnt_Contract + cnt_BusinessObject + cnt_Representation
cnt_BL_Behavior 	= cnt_BusinessService + cnt_BusinessProcess + cnt_BusinessFunction + cnt_BusinessInteraction + cnt_BusinessEvent
cnt_BL_Active   	= cnt_BusinessActor + cnt_BusinessInterface + cnt_BusinessRole + cnt_BusinessCollaboration + cnt_Location

cnt_AL_Passive  	= cnt_DataObject
cnt_AL_Behavior 	= cnt_ApplicationService + cnt_ApplicationFunction + cnt_ApplicationInteraction
cnt_AL_Active   	= cnt_ApplicationInterface + cnt_ApplicationComponent + cnt_ApplicationCollaboration

cnt_TL_Passive  	= cnt_Artifact
cnt_TL_Behavior 	= cnt_InfrastructureService + cnt_InfrastructureFunction
cnt_TL_Active   	= cnt_CommunicationPath + cnt_Network + cnt_InfrastructureInterface + cnt_Node + cnt_Device + cnt_SystemSoftware

cnt_BL_Total 		= cnt_BL_Passive + cnt_BL_Behavior + cnt_BL_Active
cnt_AL_Total 		= cnt_AL_Passive + cnt_AL_Behavior + cnt_AL_Active
cnt_TL_Total 		= cnt_TL_Passive + cnt_TL_Behavior + cnt_TL_Active

cnt_Passive_Total  	= cnt_BL_Passive + cnt_AL_Passive + cnt_TL_Passive
cnt_Behavior_Total 	= cnt_BL_Behavior + cnt_AL_Behavior + cnt_TL_Behavior
cnt_Active_Total   	= cnt_BL_Active + cnt_AL_Active + cnt_TL_Active


'--------------------
' Analyse relationships
'--------------------

call writeLog(" ")
call writeLog("Analysing relationships")
call writeLog(" ")

cnt_relations = 0

cnt_rel_BB = 0				: cnt_rel_AA = 0				: cnt_rel_TT = 0
cnt_rel_MM = 0				: cnt_rel_II = 0				: cnt_rel_BA = 0	
cnt_rel_BT = 0				: cnt_rel_BM = 0				: cnt_rel_BI = 0
cnt_rel_AT = 0				: cnt_rel_AM = 0				: cnt_rel_AI = 0
cnt_rel_TM = 0				: cnt_rel_TI = 0				: cnt_rel_MI = 0

cnt_Access = 0				: cnt_Aggregation = 0			: cnt_Assignment = 0
cnt_Association = 0			: cnt_Composition = 0			: cnt_Flow = 0
cnt_Influence = 0			: cnt_Realisation = 0			: cnt_Specialisation = 0
cnt_Triggering = 0			: cnt_UsedBy = 0

Set setRelations = xmlDoc.selectNodes("//relationship")											' Select all relationship nodes

For Each relation in setRelations																' Loop through all relationship nodes
   
	cnt_relations = cnt_relations + 1
   
	relationID     = relation.getAttribute("identifier")
	relationType   = relation.getAttribute("xsi:type")
	relationSource = relation.getAttribute("source")
	relationTarget = relation.getAttribute("target")
	
	call writeLog("Found relationship : "& relationID & " - " & relationType & ": " & relationSource & " -> " & relationTarget)
	
	Select Case relationType
	
		Case "AccessRelationship" 				cnt_Access = cnt_Access+1
		Case "AggregationRelationship" 			cnt_Aggregation = cnt_Aggregation+1
		Case "AssignmentRelationship" 			cnt_Assignment = cnt_Assignment+1
		Case "AssociationRelationship" 			cnt_Association = cnt_Association+1
		Case "CompositionRelationship" 			cnt_Composition = cnt_Composition+1
		Case "FlowRelationship" 				cnt_Flow = cnt_Flow+1
		Case "InfluenceRelationship" 			cnt_Influence = cnt_Influence+1
		Case "RealisationRelationship" 			cnt_Realisation = cnt_Realisation+1
		Case "SpecialisationRelationship" 		cnt_Specialisation = cnt_Specialisation+1
		Case "TriggeringRelationship" 			cnt_Triggering = cnt_Triggering+1
		Case "UsedByRelationship" 				cnt_UsedBy = cnt_UsedBy+1
	
	End Select
	
	relSourceType = determineLayer(relationSource)
	relTargetType = determineLayer(relationtarget)
	
	If relSourceType = "Business" and relTargetType = "Business" Then cnt_rel_BB = cnt_rel_BB + 1
	If relSourceType = "Application" and relTargetType = "Application" Then cnt_rel_AA = cnt_rel_AA + 1
	If relSourceType = "Technology" and relTargetType = "Technology" Then cnt_rel_TT = cnt_rel_TT + 1
	
	If (relSourceType = "Business" and relTargetType = "Application") _
					Or (relSourceType = "Application" and relTargetType = "Business") Then cnt_rel_BA = cnt_rel_BA + 1
	If (relSourceType = "Business" and relTargetType = "Technology") _
					Or (relSourceType = "Technology" and relTargetType = "Business") Then cnt_rel_BT = cnt_rel_BT + 1
	If (relSourceType = "Application" and relTargetType = "Technology") _
					Or (relSourceType = "Technology" and relTargetType = "Application") Then cnt_rel_AT = cnt_rel_AT + 1				
					
	If relSourceType = "Motivation" and relTargetType = "Motivation" Then cnt_rel_MM = cnt_rel_MM + 1
	If relSourceType = "Implementation" and relTargetType = "Implementation" Then cnt_rel_II = cnt_rel_II + 1				
		
	If (relSourceType = "Business" and relTargetType = "Motivation") _
					Or (relSourceType = "Motivation" and relTargetType = "Business") Then cnt_rel_BM = cnt_rel_BM + 1
	If (relSourceType = "Business" and relTargetType = "Implementation") _
					Or (relSourceType = "Implementation" and relTargetType = "Business") Then cnt_rel_BI = cnt_rel_BI + 1
	If (relSourceType = "Application" and relTargetType = "Motivation") _
					Or (relSourceType = "Motivation" and relTargetType = "Application") Then cnt_rel_AM = cnt_rel_AM + 1		
	If (relSourceType = "Application" and relTargetType = "Implementation") _
					Or (relSourceType = "Implementation" and relTargetType = "Application") Then cnt_rel_AI = cnt_rel_AI + 1
	If (relSourceType = "Technology" and relTargetType = "Motivation") _
					Or (relSourceType = "Motivation" and relTargetType = "Technology") Then cnt_rel_TM = cnt_rel_TM + 1
	If (relSourceType = "Technology" and relTargetType = "Implementation") _
					Or (relSourceType = "Implementation" and relTargetType = "Technology") Then cnt_rel_TI = cnt_rel_TI + 1
	If (relSourceType = "Motivation" and relTargetType = "Implementation") _
					Or (relSourceType = "Implementation" and relTargetType = "Motivation") Then cnt_rel_MI = cnt_rel_MI + 1					
	
Next


'--------------------
' Analyse views
'--------------------

call writeLog(" ")
call writeLog("Analysing views ...")
call writeLog(" ")

cnt_views = 0

cnt_vw_Intro = 0				: cnt_vw_BusinessFunction = 0		: cnt_vw_Product = 0
cnt_vw_ApplStructure = 0		: cnt_vw_InfraUsage = 0				: cnt_vw_ServiceReal = 0
cnt_vw_Stakeholder = 0			: cnt_vw_Principles = 0				: cnt_vw_Project = 0
cnt_vw_Organization = 0			: cnt_vw_BusinessProc = 0			: cnt_vw_ApplBehavior = 0
cnt_vw_ApplUsage = 0			: cnt_vw_ImplementDeploy = 0		: cnt_vw_Layered = 0
cnt_vw_GoalReal = 0				: cnt_vw_RequirementsReal = 0		: cnt_vw_Migration = 0
cnt_vw_ActorCoop = 0			: cnt_vw_BusinessProcCoop = 0		: cnt_vw_ApplCoop = 0
cnt_vw_Infrastructure = 0		: cnt_vw_InfoStructure = 0			: cnt_vw_LandscapeMap = 0
cnt_vw_GoalContrib = 0			: cnt_vw_Motivation = 0				: cnt_vw_ImplementMigration = 0
cnt_vw_Unknown = 0

Set setViews = xmlDoc.selectNodes("//view")														' Select all view nodes

For Each view in setViews																		' Loop through all view nodes
   
	cnt_views = cnt_views + 1
   
	viewID     	= view.getAttribute("identifier")
	viewPoint	= view.getAttribute("viewpoint")
	
	If IsNull(viewPoint) Then
        viewPoint = "No Viewpoint"
	End If
	
	Set viewLabel = view.selectSingleNode("label")
	
	If Not viewLabel Is Nothing Then
		viewName  = viewLabel.Text
	Else
		viewName  = "No Name"
	End If

	call writeLog("Found view : "& viewID & " - " & viewName & " - " & viewPoint)
	
	Select Case viewPoint
	
		Case "Introductory" 					cnt_vw_Intro = cnt_vw_vw_Intro+1
		Case "Business Function" 				cnt_vw_BusinessFunction = cnt_vw_BusinessFunction+1
		Case "Product" 							cnt_vw_Product = cnt_vw_Product+1
		Case "Application Structure" 			cnt_vw_ApplStructure = cnt_vw_ApplStructure+1
		Case "Infrastructure Usage" 			cnt_vw_InfraUsage = cnt_vw_InfraUsage+1
		Case "Service Realization" 				cnt_vw_ServiceReal = cnt_vw_ServiceReal+1
		Case "Stakeholder" 						cnt_vw_Stakeholder = cnt_vw_Stakeholder+1
		Case "Principles" 						cnt_vw_Principles = cnt_vw_Principles+1
		Case "Project" 							cnt_vw_Project = cnt_vw_Project+1
		Case "Organization" 					cnt_vw_Organization = cnt_vw_Organization+1
		Case "Business Process" 				cnt_vw_BusinessProc = cnt_vw_BusinessProc+1
		Case "Application Behavior" 			cnt_vw_ApplBehavior = cnt_vw_ApplBehavior+1
		Case "Application Usage" 				cnt_vw_ApplUsage = cnt_vw_ApplUsage+1
		Case "Implementation and Deployment" 	cnt_vw_ImplementDeploy = cnt_vw_ImplementDeploy+1
		Case "Layered" 							cnt_vw_Layered = cnt_vw_Layered+1
		Case "Goal Realization" 				cnt_vw_GoalReal = cnt_vw_GoalReal+1
		Case "Requirements Realization" 		cnt_vw_RequirementsReal = cnt_vw_RequirementsReal+1
		Case "Migration" 						cnt_vw_Migration = cnt_vw_Migration+1
		Case "Actor Co-operation" 				cnt_vw_ActorCoop = cnt_vw_ActorCoop+1
		Case "Business Process Co-operation" 	cnt_vw_BusinessProcCoop = cnt_vw_BusinessProcCoop+1
		Case "Application Co-operation" 		cnt_vw_ApplCoop = cnt_vw_ApplCoop+1
		Case "Infrastructure" 					cnt_vw_Infrastructure = cnt_vw_Infrastructure+1
		Case "Information Structure" 			cnt_vw_InfoStructure = cnt_vw_InfoStructure+1
		Case "Landscape Map" 					cnt_vw_LandscapeMap = cnt_vw_LandscapeMap+1
		Case "Goal Contribution" 				cnt_vw_GoalContrib = cnt_vw_GoalContrib+1
		Case "Motivation" 						cnt_vw_Motivation = cnt_vw_Motivation+1
		Case "Implementation and Migration" 	cnt_vw_ImplementMigration = cnt_vw_ImplementMigration+1
		Case "No Viewpoint"						cnt_vw_Unknown = cnt_vw_Unknown+1
	
	End Select
	
Next


'--------------------
' Open template xls
'--------------------

Set objExcel = CreateObject("Excel.Application")
Set objWorkbook = objExcel.Workbooks.Open (xlsTemplate)

Set objWorksheet = objWorkbook.Worksheets("values")


'--------------------
' Write results to log and xls
'--------------------

call writeLog("-------------------------------------------------------------------")

call updateExcel(1,2,modelName)
call updateExcel(1,6,inputFile)
call updateExcel(2,6,Day(Date) & "-" & Month(Date) & "-" & Year(Date) & " " & Time)

call writeLog(" ")
call writeLog("Total number of elements found : " & cnt_elements)			: call updateExcel(5,2,cnt_elements)
call writeLog("Total number of relationships found : "& cnt_relations)		: call updateExcel(6,2,cnt_relations)
call writeLog("Total number of views found : "& cnt_views)					: call updateExcel(7,2,cnt_views)

call writeLog(" ")
call writeLog("Number of BusinessObject occurences : " & cnt_BusinessObject)				: call updateExcel(12,2,cnt_BusinessObject)
call writeLog("Number of Representation occurences : " & cnt_Representation)				: call updateExcel(13,2,cnt_Representation)
call writeLog("Number of Meaning occurences : " & cnt_Meaning)								: call updateExcel(14,2,cnt_Meaning)
call writeLog("Number of Value occurences : " & cnt_Value)									: call updateExcel(15,2,cnt_Value)
call writeLog("Number of Product occurences : " & cnt_Product)								: call updateExcel(16,2,cnt_Product)
call writeLog("Number of Contract occurences : " & cnt_Contract)							: call updateExcel(17,2,cnt_Contract)
call writeLog("Number of BusinessProcess occurences : " & cnt_BusinessProcess)				: call updateExcel(18,2,cnt_BusinessProcess)
call writeLog("Number of BusinessFunction occurences : " & cnt_BusinessFunction)			: call updateExcel(19,2,cnt_BusinessFunction)
call writeLog("Number of BusinessInteraction occurences : " & cnt_BusinessInteraction)		: call updateExcel(20,2,cnt_BusinessInteraction)	
call writeLog("Number of BusinessEvent occurences : " & cnt_BusinessEvent)					: call updateExcel(21,2,cnt_BusinessEvent)
call writeLog("Number of BusinessService occurences : " & cnt_BusinessService)				: call updateExcel(22,2,cnt_BusinessService)	
call writeLog("Number of BusinessActor occurences : " & cnt_BusinessActor)					: call updateExcel(23,2,cnt_BusinessActor)
call writeLog("Number of BusinessRole occurences : " & cnt_BusinessRole)					: call updateExcel(24,2,cnt_BusinessRole)
call writeLog("Number of BusinessCollaboration occurences : " & cnt_BusinessCollaboration)	: call updateExcel(25,2,cnt_BusinessCollaboration)	
call writeLog("Number of BusinessInterface occurences : " & cnt_BusinessInterface)			: call updateExcel(26,2,cnt_BusinessInterface)
call writeLog("Number of Location occurences : " & cnt_Location)							: call updateExcel(27,2,cnt_Location)

call writeLog(" ")
call writeLog("Number of DataObject occurences : " & cnt_DataObject)								: call updateExcel(12,6,cnt_DataObject)
call writeLog("Number of ApplicationFunction occurences : " & cnt_ApplicationFunction)				: call updateExcel(13,6,cnt_ApplicationFunction)
call writeLog("Number of ApplicationInteraction occurences : " & cnt_ApplicationInteraction)		: call updateExcel(14,6,cnt_ApplicationInteraction)
call writeLog("Number of ApplicationService occurences : " & cnt_ApplicationService)				: call updateExcel(15,6,cnt_ApplicationService)
call writeLog("Number of ApplicationComponent occurences : " & cnt_ApplicationComponent)			: call updateExcel(16,6,cnt_ApplicationComponent)
call writeLog("Number of ApplicationCollaboration occurences : " & cnt_ApplicationCollaboration)	: call updateExcel(17,6,cnt_ApplicationCollaboration)
call writeLog("Number of ApplicationInterface occurences : " & cnt_ApplicationInterface)			: call updateExcel(18,6,cnt_ApplicationInterface)

call writeLog(" ")
call writeLog("Number of Artifact occurences : " & cnt_Artifact)									: call updateExcel(22,6,cnt_Artifact)
call writeLog("Number of InfrastructureFunction occurences : " & cnt_InfrastructureFunction)		: call updateExcel(23,6,cnt_InfrastructureFunction)
call writeLog("Number of InfrastructureService occurences : " & cnt_InfrastructureService)			: call updateExcel(24,6,cnt_InfrastructureService)
call writeLog("Number of Node occurences : " & cnt_Node)											: call updateExcel(25,6,cnt_Node)
call writeLog("Number of Device occurences : " & cnt_Device)										: call updateExcel(26,6,cnt_Device)
call writeLog("Number of SystemSoftware occurences : " & cnt_SystemSoftware)						: call updateExcel(27,6,cnt_SystemSoftware)
call writeLog("Number of InfrastructureInterface occurences : " & cnt_InfrastructureInterface)		: call updateExcel(28,6,cnt_InfrastructureInterface)
call writeLog("Number of Network occurences : " & cnt_Network)										: call updateExcel(29,6,cnt_Network)
call writeLog("Number of CommunicationPath occurences : " & cnt_CommunicationPath)					: call updateExcel(30,6,cnt_CommunicationPath)

call writeLog(" ")
call writeLog("Number of Stakeholder occurences : " & cnt_Stakeholder)		: call updateExcel(12,10,cnt_Stakeholder)
call writeLog("Number of Driver occurences : " & cnt_Driver)				: call updateExcel(13,10,cnt_Driver)
call writeLog("Number of Assessment occurences : " & cnt_Assessment)		: call updateExcel(14,10,cnt_Assessment)
call writeLog("Number of Goal occurences : " & cnt_Goal)					: call updateExcel(15,10,cnt_Goal)
call writeLog("Number of Requirement occurences : " & cnt_Requirement)		: call updateExcel(16,10,cnt_Requirement)
call writeLog("Number of Constraint occurences : " & cnt_Constraint)		: call updateExcel(17,10,cnt_Constraint)
call writeLog("Number of Principle occurences : " & cnt_Principle)			: call updateExcel(18,10,cnt_Principle)

call writeLog(" ")
call writeLog("Number of WorkPackage occurences : " & cnt_WorkPackage)		: call updateExcel(22,10,cnt_WorkPackage)
call writeLog("Number of Deliverable occurences : " & cnt_Deliverable)		: call updateExcel(23,10,cnt_Deliverable)
call writeLog("Number of Plateau occurences : " & cnt_Plateau)				: call updateExcel(24,10,cnt_Plateau)
call writeLog("Number of Gap occurences : " & cnt_Gap)						: call updateExcel(25,10,cnt_Gap)

call writeLog(" ")
call writeLog("Sum of Business Layer elements    : " & cnt_BL_Total)		: call updateExcel(28,2,cnt_BL_Total)
call writeLog("Sum of Application Layer elements : " & cnt_AL_Total)		: call updateExcel(19,6,cnt_AL_Total)
call writeLog("Sum of Technology Layer elements  : " & cnt_TL_Total)		: call updateExcel(31,6,cnt_TL_Total)

call writeLog(" ")
call writeLog("Sum of Passive Structure elements : " & cnt_Passive_Total)	: call updateExcel(29,10,cnt_Passive_Total)
call writeLog("Sum of Behavior elements          : " & cnt_Behavior_Total)	: call updateExcel(30,10,cnt_Behavior_Total)
call writeLog("Sum of Active Structure elements  : " & cnt_Active_Total)	: call updateExcel(31,10,cnt_Active_Total)

call writeLog(" ")
call writeLog("Sum of Business Layer Passive Structure elements    : " & cnt_BL_Passive)	: call updateExcel(17,3,cnt_BL_Passive)
call writeLog("Sum of Business Layer Behavior elements             : " & cnt_BL_Behavior)	: call updateExcel(22,3,cnt_BL_Behavior)
call writeLog("Sum of Business Layer Active Structure elements     : " & cnt_BL_Active)		: call updateExcel(27,3,cnt_BL_Active)
call writeLog("Sum of Application Layer Passive Structure elements : " & cnt_AL_Passive)	: call updateExcel(12,7,cnt_AL_Passive)
call writeLog("Sum of Application Layer Behavior elements          : " & cnt_AL_Behavior)	: call updateExcel(15,7,cnt_AL_Behavior)
call writeLog("Sum of Application Layer Active Structure elements  : " & cnt_AL_Active)		: call updateExcel(18,7,cnt_AL_Active)
call writeLog("Sum of Technology Layer Passive Structure elements  : " & cnt_TL_Passive)	: call updateExcel(22,7,cnt_TL_Passive)
call writeLog("Sum of Technology Layer Behavior elements           : " & cnt_TL_Behavior)	: call updateExcel(24,7,cnt_TL_Behavior)
call writeLog("Sum of Technology Layer Active Structure elements   : " & cnt_TL_Active)		: call updateExcel(30,7,cnt_TL_Active)

call writeLog(" ")
call writeLog("Sum of Composition Relationships : " & cnt_Composition)			: call updateExcel(42,2,cnt_Composition)
call writeLog("Sum of Aggregation Relationships : " & cnt_Aggregation)			: call updateExcel(43,2,cnt_Aggregation)
call writeLog("Sum of Assignment Relationships : " & cnt_Assignment)			: call updateExcel(44,2,cnt_Assignment)
call writeLog("Sum of Realisation Relationships : " & cnt_Realisation)			: call updateExcel(45,2,cnt_Realisation)
call writeLog("Sum of UsedBy Relationships : " & cnt_UsedBy)					: call updateExcel(46,2,cnt_UsedBy)
call writeLog("Sum of Access Relationships : " & cnt_Access)					: call updateExcel(47,2,cnt_Access)
call writeLog("Sum of Association Relationships : " & cnt_Association)			: call updateExcel(48,2,cnt_Association)
call writeLog("Sum of Triggering Relationships : " & cnt_Triggering)			: call updateExcel(49,2,cnt_Triggering)
call writeLog("Sum of Flow Relationships : " & cnt_Flow)						: call updateExcel(50,2,cnt_Flow)
call writeLog("Sum of Influence Relationships : " & cnt_Influence)				: call updateExcel(51,2,cnt_Influence)
call writeLog("Sum of Specialisation Relationships : " & cnt_Specialisation)	: call updateExcel(52,2,cnt_Specialisation)
	
call writeLog(" ")
call writeLog("Number of relationships within the Business Layer    : " & cnt_rel_BB )		: call updateExcel(42,6,cnt_rel_BB)
call writeLog("Number of relationships within the Application Layer : " & cnt_rel_AA )		: call updateExcel(43,6,cnt_rel_AA)
call writeLog("Number of relationships within the Technology Layer  : " & cnt_rel_TT )		: call updateExcel(44,6,cnt_rel_TT)

call writeLog(" ")
call writeLog("Number of cross-layer relationships between the Business Layer and the Application Layer   : " & cnt_rel_BA )	: call updateExcel(45,6,cnt_rel_BA)
call writeLog("Number of cross-layer relationships between the Application Layer and the Technology Layer : " & cnt_rel_AT )	: call updateExcel(46,6,cnt_rel_AT)
call writeLog("Number of cross-layer relationships between the Business Layer and the Technology Layer    : " & cnt_rel_BT )	: call updateExcel(47,6,cnt_rel_BT)

call writeLog(" ")
call writeLog("Number of relationships within the Motivation Extension     : " & cnt_rel_MM )	: call updateExcel(42,10,cnt_rel_MM)
call writeLog("Number of relationships within the Implementation Extension : " & cnt_rel_II )	: call updateExcel(43,10,cnt_rel_II)

call writeLog(" ")
call writeLog("Number of relationships between the Motivation Extension and the Business Layer    : " & cnt_rel_BM )	: call updateExcel(44,10,cnt_rel_BM)
call writeLog("Number of relationships between the Motivation Extension and the Application Layer : " & cnt_rel_AM )	: call updateExcel(45,10,cnt_rel_AM)
call writeLog("Number of relationships between the Motivation Extension and the Technology Layer  : " & cnt_rel_TM )	: call updateExcel(46,10,cnt_rel_TM)

call writeLog(" ")
call writeLog("Number of relationships between the Implementation Extension and the Business Layer    : " & cnt_rel_BI )	: call updateExcel(47,10,cnt_rel_BI)
call writeLog("Number of relationships between the Implementation Extension and the Application Layer : " & cnt_rel_AI )	: call updateExcel(48,10,cnt_rel_AI)
call writeLog("Number of relationships between the Implementation Extension and the Technology Layer  : " & cnt_rel_TI )	: call updateExcel(49,10,cnt_rel_TI)

call writeLog(" ")
call writeLog("Number of relationships between the Motivation Extension and the Implementation Extension : " & cnt_rel_MI )		: call updateExcel(50,10,cnt_rel_MI)

call writeLog(" ")
call writeLog("Sum of Introductory Viewpoints : " & cnt_vw_Intro)									: call updateExcel(57,2,cnt_vw_Intro)
call writeLog("Sum of Organization Viewpoints : " & cnt_vw_Organization)							: call updateExcel(58,2,cnt_vw_Organization)
call writeLog("Sum of Actor Co-operation Viewpoints : " & cnt_vw_ActorCoop)							: call updateExcel(59,2,cnt_vw_ActorCoop)
call writeLog("Sum of Business Function Viewpoints : " & cnt_vw_BusinessFunction)					: call updateExcel(60,2,cnt_vw_BusinessFunction)
call writeLog("Sum of Business Process Viewpoints : " & cnt_vw_BusinessProc)						: call updateExcel(61,2,cnt_vw_BusinessProc)
call writeLog("Sum of Business Process Co-operation Viewpoints : " & cnt_vw_BusinessProcCoop)		: call updateExcel(62,2,cnt_vw_BusinessProcCoop)
call writeLog("Sum of Product Viewpoints : " & cnt_vw_Product)										: call updateExcel(63,2,cnt_vw_Product)
call writeLog("Sum of Application Behavior Viewpoints : " & cnt_vw_ApplBehavior)					: call updateExcel(64,2,cnt_vw_ApplBehavior)
call writeLog("Sum of Application Co-operation Viewpoints : " & cnt_vw_ApplCoop)					: call updateExcel(65,2,cnt_vw_ApplCoop)
call writeLog("Sum of Application Structure Viewpoints : " & cnt_vw_ApplStructure)					: call updateExcel(66,2,cnt_vw_ApplStructure)
call writeLog("Sum of Application Usage Viewpoints : " & cnt_vw_ApplUsage)							: call updateExcel(67,2,cnt_vw_ApplUsage)	
call writeLog("Sum of Infrastructure Viewpoints : " & cnt_vw_Infrastructure)						: call updateExcel(68,2,cnt_vw_Infrastructure)
call writeLog("Sum of Infrastructure Usage Viewpoints : " & cnt_vw_InfraUsage)						: call updateExcel(69,2,cnt_vw_InfraUsage)
call writeLog("Sum of Implementation and Deployment Viewpoints : " & cnt_vw_ImplementDeploy)		: call updateExcel(70,2,cnt_vw_ImplementDeploy)
call writeLog("Sum of Information Structure Viewpoints : " & cnt_vw_InfoStructure)					: call updateExcel(71,2,cnt_vw_InfoStructure)
call writeLog("Sum of Service Realization Viewpoints : " & cnt_vw_ServiceReal)						: call updateExcel(72,2,cnt_vw_ServiceReal)
call writeLog("Sum of Layered Viewpoints : " & cnt_vw_Layered)										: call updateExcel(73,2,cnt_vw_Layered)
call writeLog("Sum of Landscape Map Viewpoints : " & cnt_vw_LandscapeMap)							: call updateExcel(74,2,cnt_vw_LandscapeMap)
call writeLog("Sum of views without a defined Type : " & cnt_vw_Unknown)							: call updateExcel(75,2,cnt_vw_Unknown)

call writeLog("Sum of Stakeholder Viewpoints : " & cnt_vw_Stakeholder)								: call updateExcel(57,6,cnt_vw_Stakeholder)
call writeLog("Sum of Goal Realization Viewpoints : " & cnt_vw_GoalReal)							: call updateExcel(58,6,cnt_vw_GoalReal)
call writeLog("Sum of Goal Contribution Viewpoints : " & cnt_vw_GoalContrib)						: call updateExcel(59,6,cnt_vw_GoalContrib)
call writeLog("Sum of Principles Viewpoints : " & cnt_vw_Principles)								: call updateExcel(60,6,cnt_vw_Principles)
call writeLog("Sum of Requirements Realization Viewpoints : " & cnt_vw_RequirementsReal)			: call updateExcel(61,6,cnt_vw_RequirementsReal)
call writeLog("Sum of Motivation Viewpoints : " & cnt_vw_Motivation)								: call updateExcel(62,6,cnt_vw_Motivation)

call writeLog("Sum of Project Viewpoints : " & cnt_vw_Project)										: call updateExcel(63,6,cnt_vw_Project)
call writeLog("Sum of Migration Viewpoints : " & cnt_vw_Migration)									: call updateExcel(64,6,cnt_vw_Migration)
call writeLog("Sum of Implementation and Migration Viewpoints : " & cnt_vw_ImplementMigration)		: call updateExcel(65,6,cnt_vw_ImplementMigration)

call writeLog(" ")
call writeLog("Script Finished !")

objExcel.DisplayAlerts = FALSE
objExcel.ActiveWorkbook.SaveAs xlsFile
objExcel.DisplayAlerts = FALSE

objExcel.ActiveWorkbook.ExportAsFixedFormat 0, pdfFile, 0, TRUE, FALSE, , , FALSE
objExcel.ActiveWorkbook.Close

    
objExcel.Quit

msgbox "Archimate Model Exchange File Analyzer v3.0" & vbCRLF & vbCRLF & "Analysis is finished ! "

Set objWSH = CreateObject("WScript.Shell")
objWSH.Run Chr(34) & pdfFile & Chr(34)


'--------------------
' Subroutines
'--------------------

Function determineLayer(ByVal identifier)

	elementPath =  "/model/elements/element[@identifier = '" & identifier & "']" 
	Set elementNode    = xmlDoc.selectSingleNode(elementPath)
	
	If Not elementNode Is Nothing Then
	
		elementType = elementNode.getAttribute("xsi:type")
		
		Select Case elementType
	
			Case "BusinessActor" 			determineLayer = "Business"
			Case "BusinessInterface" 		determineLayer = "Business"
			Case "BusinessRole" 			determineLayer = "Business"
			Case "BusinessCollaboration" 	determineLayer = "Business"
			Case "Location" 				determineLayer = "Business"
			Case "BusinessService" 			determineLayer = "Business"
			Case "BusinessProcess" 			determineLayer = "Business"
			Case "BusinessFunction" 		determineLayer = "Business"
			Case "BusinessInteraction" 		determineLayer = "Business"
			Case "BusinessEvent" 			determineLayer = "Business"
			Case "Value" 					determineLayer = "Business"
			Case "Product" 					determineLayer = "Business"
			Case "Meaning" 					determineLayer = "Business"
			Case "Contract" 				determineLayer = "Business"
			Case "BusinessObject" 			determineLayer = "Business"
			Case "Representation" 			determineLayer = "Business"
		
			Case "ApplicationInterface" 	determineLayer = "Application"
			Case "ApplicationComponent" 	determineLayer = "Application"
			Case "ApplicationCollaboration" determineLayer = "Application"
			Case "ApplicationService" 		determineLayer = "Application"
			Case "ApplicationFunction" 		determineLayer = "Application"
			Case "ApplicationInteraction" 	determineLayer = "Application"
			Case "DataObject" 				determineLayer = "Application"
		
			Case "CommunicationPath" 		determineLayer = "Technology"
			Case "Network" 					determineLayer = "Technology"
			Case "InfrastructureInterface" 	determineLayer = "Technology"
			Case "Node" 					determineLayer = "Technology"
			Case "Device" 					determineLayer = "Technology"
			Case "InfrastructureService" 	determineLayer = "Technology"
			Case "InfrastructureFunction" 	determineLayer = "Technology"
			Case "SystemSoftware" 			determineLayer = "Technology"
			Case "Artifact" 				determineLayer = "Technology"
		
			Case "Requirement" 				determineLayer = "Motivation"
			Case "Constraint" 				determineLayer = "Motivation"
			Case "Principle" 				determineLayer = "Motivation"
			Case "Goal" 					determineLayer = "Motivation"
			Case "Stakeholder" 				determineLayer = "Motivation"
			Case "Assessment" 				determineLayer = "Motivation"
			Case "Driver" 					determineLayer = "Motivation"
		
			Case "WorkPackage" 				determineLayer = "Implementation"
			Case "Deliverable" 				determineLayer = "Implementation"
			Case "Plateau" 					determineLayer = "Implementation"
			Case "Gap" 						determineLayer = "Implementation"
		
			Case "Junction" 				determineLayer = "Junction"
		
	End Select
		
		
	
	Else
	
		call writeLog("--->Warning : element with ID : " & identifier & " doesn't exist")
		determineLayer = "Unknown"
	
	End If
	
End Function


Sub writeLog(ByVal messageSTR)

	curDate =  Day(Date) & "-" & Month(Date) & "-" & Year(Date) & " " & Time

	objLog.WriteLine curDate & "  " & MessageSTR

End Sub


Sub UpdateExcel(ByVal row, ByVal column, ByVal value)

	objWorksheet.Cells(row,column).Value = value

End Sub

